## 0.0.8 - 2022-02-03

### Added

- [#148](https://github.com/edgarrmondragon/citric/pull/148) Implement `add_group` in client
- [#148](https://github.com/edgarrmondragon/citric/pull/148) Implement `import_question` in client
